| VDPO-package | R Documentation |
Comprehensive set of tools for analyzing and manipulating functional data with non-uniform lengths. This package addresses two common scenarios in functional data analysis: Variable Domain Data, where the observation domain differs across samples, and Partially Observed Data, where observations are incomplete over the domain of interest. 'VDPO' enhances the flexibility and applicability of functional data analysis in 'R'. See Amaro et al. (2024) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.48550/arXiv.2401.05839")}.
Maintainer: Pavel Hernandez pavel.amaro96@gmail.com
Authors:
Pavel Hernandez pavel.amaro96@gmail.com
Other contributors:
Jose Ignacio Diez jodiezru@pa.uc3m.es [contractor]
Maria Durban mdurban@est-econ.uc3m.es [contributor]
Maria del Carmen Aguilera-Morillo mdagumor@eio.upv.es [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.