| add_grid | R Documentation |
It prepared the partially observed data to be inputed in the ffpo function.
This function should only be used when the bidimensional_grid
parameter of the ffpo function is FALSE.
add_grid(df, grid)
df |
|
grid |
Grid vector. |
data.frame with the grid added.
ffpo
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.