| ffpo_2d | R Documentation |
Auxiliary function used to define ffpo_2d terms within VDPO model
formulae.
ffpo_2d(X, miss_points, missing_points, nbasis = rep(15, 4), bdeg = rep(3, 4))
X |
partially observed bidimensional functional covariate |
miss_points, missing_points |
|
nbasis |
number of basis to be used. |
bdeg |
degree of the basis to be used. |
The difference between miss_points and missing_points is the format in which the data is presented.
miss_points is a list of lists where each inner list corresponds
to the observation points in the y-axis and contains the observation points
of the missing values for the x-axis. miss_points acts as a guide for
identifying and addressing missing observations in functional data and is used
for properly calculating the inner product matrix.
missing_points is a list where each element is a matrix
containing the missing observations points.
The function is interpreted in the formula of a VDPO model.
list containing the following elements:
B_ffpo2d design matrix.
Phi_ffpo2d bidimensional B-spline basis used for the functional coefficient.
M_ffpo2d the missing_points used as input in the function.
nbasis number of the basis used.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.